@@ -396,7 +396,9 @@ nextword(){
 
       if(html_f != 0 || script != 0 || style != 0 || CMNT != 0) continue;
 
-      if(ch == '[' || ch == ']' || ch == '(') break;
+      if(ch == '[' || ch == '(') break;
+      //      if(ch == '[' || ch == ']' || ch == '(') break;
+      if(strcmp(buf, "g") == 0 || strcmp(buf, "e") == 0) break;
       if(ch == '?' || ch == '!' || ch == ';') break;
       if(ch == '\'' && i == 1) break;
       if((strstr(buf, ".com") || strstr(buf, ".jp") || strstr(buf, ".gov")) && !strstr(buf, "http://")) break;
@@ -444,7 +446,7 @@ expression(){
         if(buf[strlen(buf)-1] == '.') c = '.';
       }
       strcat(egs, buf);
-      if(strncmp(buf, "&#", 2) == 0) break;
+      //      if(strncmp(buf, "&#", 2) == 0) break;
 //   fprintf(dbg, "--- exp --- egs = %s script = %d \n", egs, script);
       // html֐̃`FbN =1
       if(*buf == '<' || script != 0 || strstr(buf, "---")) return(1);
@@ -453,6 +455,7 @@ expression(){
 //   fprintf(dbg, "--- exp --- egs = %s script = %d \n", egs, script);
 
       if(strcmp(buf+strlen(buf)-2, ".\"") == 0) break; // buf : xxxx." 15/08/08
+      if(strcmp(buf+strlen(buf)-3, ".h") == 0) break; // buf : xxxx." 15/11/02
       if(c == '<') break;
       if(c == '!' || c == '?' || c == ']') break;
       if(c == ':' && isdigit(buf[strlen(buf)-2])==0) break;
@@ -523,7 +526,10 @@ expression(){
       }
     }
     if(egs[0] == '\0') return(0);
-    if(strstr(egs, "&#") || strstr(egs, "&bull;") || strstr(egs, "&raquo;")) return(1);
+    if(ptc = strstr(egs, "&#")){
+      if(strncmp(ptc, "&#8212;", 7)) return(1); // em_bVȊO̎
+    }
+    if( strstr(egs, "&bull;") || strstr(egs, "&raquo;")) return(1);
     if((ptc = (char*)strchr(egs, '%')) && !isdigit(*(ptc-1))) return(1);
     if((ptc = (char*)strstr(egs, "@import")) ) return(1);
     // style Lēx̗p 20/8/16
