@@ -315,6 +315,10 @@ char bj[], bz[];
     int  t, j, ln, lz, l3;
     char ctck[60], cz3[60], bjq[JSentLen], *ptj, c;
  if(Dbg == 'Y') fprintf(dbg, "--- sopresv --- bj = %s bz = %s cz = %s \n", bj, bz, cz[wc+i]);
+    // 15/12/20
+ if(Dbg == 'Y') fprintf(dbg, "--- sopresv --- md[i] = %d \n", md[i]);
+    if(strlen(md[i]) > 80) return;   // sj̒= 80
+
     strcpy(cz3, cz[wc+i]);
     if(*bz == 'b'){
       ptj = (char*)index(bz+1, 'b');
@@ -340,8 +344,10 @@ char bj[], bz[];
 	if(! index(ctck, cz3[t])) ctck[++j] = cz3[t];
       }
       strcpy(cz[wc+i], ctck);
-      if(strlen(bz) + strlen(ctck) > 30){
-	printf("\n The length of bz excedes 30 !! \n");
+      if(strlen(bz) + strlen(ctck) > 50){  // 30 -> CzLen/2 = 50
+	printf("\n The length of bz excedes 50 !! \n");
+ if(Dbg == 'Y') fprintf(dbg, "--- sopresv --- The bz_length excede 30 !! \n");
+        return;
 	printf(" p܂ [Y/N]= ");	c = '\0';
 	while(c != 'y' && c != 'n') c = tolower(getchar());
         if(c != 'y') exit(1);
@@ -352,6 +358,7 @@ char bj[], bz[];
     strcat(bz, cz[wc+i]);
     strcpy(bjq, md[i]);
     ln = strlen(bjq);
+
     /*
     if(ptj = (char*)strstr(bjq, "i")){
       ptptcut(bjq+1, ptj+1);	ln = strlen(bjq);
@@ -429,7 +436,7 @@ char mdi[], mzi[], mdj[], mzj[];
     if(strncmp(mdi+1, "almost ", 7) == 0) return;
     if(strncmp(mdi+1, "there are", 9) == 0) return;
     if(strncmp(mdi+1, "there be", 8) == 0 ){
-      if(strstr(mzj, "") ){
+      if(strstr(mzj, "") || strchr(mzj, 'n') ){
 	ptreplace(mdi+7, 2, "are");    return;
       }
 	ptreplace(mdi+7, 2, "is");    return;
@@ -522,7 +529,7 @@ char mdi[], mzi[], mdj[], mzj[];
         || strncmp(pt-2, "sh", 2) == 0 || strncmp(pt-2, "ch", 2) == 0)
           ptinsert(pt, "es");
         else if(*(pt-1) == 'y') ptreplace(pt-1, 1, "ies");
-        else ptinsert(pt, "s");
+        else if(strlen(mdi+1)!=0) ptinsert(pt, "s");
 
     }
     else{
@@ -557,6 +564,9 @@ char *str, *ptone;
         if(strchr(mz[j], 'W')){ ptreplace(ptone, 3, "her");    return; }
         else {
           if(strncmp(ptone, "one's", 5) == 0) {
+	    if(strcmp(str, "I") == 0){
+              ptreplace(ptone, 5, "my");    return;
+	    }
             ptreplace(ptone, 5, "his");    return;
           }
 	  //          ptreplace(ptone, 3, "him");    return; 
